import { Button } from '@/components/ui/button';
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import { Carousel, CarouselContent, CarouselItem } from '@/components/ui/carousel';
import { Link } from '@inertiajs/react';
import { Clock, MapPin, Users } from 'lucide-react';
import { useEffect, useState } from 'react';

const groupTours = [
    {
        id: 'classic-tour',
        title: 'Classic Tour - 14 Days',
        description: `
            For many travellers, Sri Lanka has long flown under the radar — but it’s making a strong return.
            Discover the vibrant colours, rich cultures, and swaying palm trees of this tropical gem. Journey
            through tea plantations and ancient rock fortresses on this carefully crafted 14-day tour. More
            than just beaches and breathtaking views, this adventure is about the inspiring people you’ll
            encounter along the way.
        `,
        image: '/tours/group/class-tour.jpg',
        duration: '14 Days',
        groupSize: 'Max 15 - Minimum 5',
        price: '$950',
    },
    {
        id: '18-40-tour',
        title: "18 to 40's - 12 Days",
        description: `Embark on a captivating 12-day journey through Sri Lanka, a land of rich culture, breathtaking landscapes, and warm hospitality. From the bustling streets of Colombo to the ancient wonders of Sigiriya, the sacred city of Kandy, the lush hill country of Ella, and the sun-kissed beaches of Mirissa — this immersive tour offers the perfect blend of heritage, adventure, relaxation, and natural beauty.

`,
        image: '/tours/group/18-tour.jpg',
        duration: '12 Days',
        groupSize: '2-16',
        price: '$750',
    },
    {
        id: 'in-to-the-wilderness',
        title: 'In to the Wilderness - 10 Days',
        description: `Dive into an extraordinary 8-day adventure across Sri Lanka - a land of timeless temples, misty mountains, vibrant wildlife, 
        and sun-kissed shores. From the ancient wonders of the Cultural Triangle to the emerald tea country and the charm of coastal life, this journey offers a perfect balance of exploration, relaxation, and unforgettable encounters with nature and heritage.`,
        image: '/tours/group/in-to-the-wilderness.jpg',
        duration: '10 Days',
        groupSize: '2-16',
        price: '$1200',
    },
];

const individualTours = [
    {
        id: 4,
        title: 'Culture Triangle',
        description:
            'Explore the heart of Sri Lankan culture with visits to ancient cities and sacred sites. Discover the ancient cities of Anuradhapura, Polonnaruwa, and climb Sigiriya Rock Fortress. Discover the ancient cities of Anuradhapura, Polonnaruwa, and climb Sigiriya Rock Fortress. Discover the ancient cities of Anuradhapura, Polonnaruwa, and climb Sigiriya Rock Fortress.',
        image: '/tours/individual/1.jpg',
        duration: '8 Days',
        location: 'Anuradhapura, Polonnaruwa, Kandy',
        groupSize: '2-6',
        price: '$799',
    },
    {
        id: 5,
        title: 'Honeymoon',
        description: "Romantic getaway exploring Sri Lanka's most beautiful beaches and scenic landscapes.",
        image: '/tours/individual/2.jpg',
        duration: '10 Days',
        location: 'Bentota, Ella, Nuwara Eliya',
        groupSize: '2',
        price: '$1299',
    },
    {
        id: 6,
        title: 'Family Tours',
        description: 'Family-friendly adventures with activities suitable for all ages.',
        image: '/tours/individual/3.jpg',
        duration: '12 Days',
        location: 'Colombo, Kandy, Galle',
        groupSize: '2-8',
        price: '$1099',
    },
    {
        id: 7,
        title: 'Hiking',
        description: "Trek through Sri Lanka's stunning mountains and experience breathtaking views.",
        image: '/tours/individual/4.jpg',
        duration: '7 Days',
        location: "Knuckles, Ella Rock, Adam's Peak",
        groupSize: '2-10',
        price: '$849',
    },
];

type Tour = {
    id: number;
    title: string;
    description: string;
    image: string;
    duration: string;
    location: string;
    groupSize: string;
    price: string;
};

const GroupTourCard = ({ tour }: { tour: Tour }) => (
    <Card className="tour-card h-full overflow-hidden border-0 shadow-md transition-shadow">
        <div className="h-80 overflow-hidden">
            <img src={tour.image} alt={tour.title} className="tour-image h-full w-full object-cover" />
        </div>
        <CardHeader>
            <CardTitle className="font-display text-xl">{tour.title}</CardTitle>
            <CardDescription className="line-clamp-2">{tour.description}</CardDescription>
        </CardHeader>
        <CardContent>
            <div className="flex flex-col space-y-2">
                <div className="flex items-center text-sm text-gray-500">
                    <Clock size={16} className="mr-2" />
                    <span>{tour.duration}</span>
                </div>

                <div className="flex items-center text-sm text-gray-500">
                    <Users size={16} className="mr-2" />
                    <span>{tour.groupSize} people</span>
                </div>
            </div>
        </CardContent>
        <CardFooter className="flex items-center justify-between border-t pt-4">
            <div className="text-primary text-lg font-bold">From {tour.price}</div>
            <Button size="sm" className="rounded-full" asChild>
                <Link href={`/tour/${tour.id}`}>View Details</Link>
            </Button>
        </CardFooter>
    </Card>
);

const IndividualTourCard = ({ tour }: { tour: Tour }) => (
    <Card className="tour-card border-l-primary h-full overflow-hidden border-0 border-l-4 bg-green-50 shadow-md transition-shadow hover:shadow-xl">
        <div className="flex h-full flex-col md:flex-row">
            <div className="h-48 overflow-hidden md:h-auto md:w-2/5">
                <img src={tour.image} alt={tour.title} className="tour-image w-full object-cover" />
            </div>
            <div className="flex flex-col md:w-3/5">
                <CardHeader className="bg-gradient-to-r from-green-100 to-transparent">
                    <CardTitle className="font-display text-xl text-green-800">{tour.title}</CardTitle>
                    <CardDescription className="line-clamp-2">{tour.description}</CardDescription>
                </CardHeader>
                <CardContent>
                    <div className="flex flex-col space-y-2">
                        <div className="mt-3 flex items-center text-sm text-green-700">
                            <Clock size={16} className="mr-2" />
                            <span>{tour.duration}</span>
                        </div>
                        <div className="flex items-center text-sm text-green-700">
                            <MapPin size={16} className="mr-2" />
                            <span>{tour.location}</span>
                        </div>
                        <div className="flex items-center text-sm text-green-700">
                            <Users size={16} className="mr-2" />
                            <span>{tour.groupSize} people</span>
                        </div>
                    </div>
                </CardContent>
                <CardFooter className="mt-auto flex items-center justify-between border-t border-green-200 pt-4">
                    <div className="text-lg font-bold text-green-700">{tour.price}</div>
                    <Button size="sm" className="rounded-full bg-green-700 hover:bg-green-800" asChild>
                        <Link href={`/tour/${tour.id}`}>View Details</Link>
                    </Button>
                </CardFooter>
            </div>
        </div>
    </Card>
);

const TourPackages = () => {
    const [groupApi, setGroupApi] = useState(null);
    const [individualApi, setIndividualApi] = useState(null);

    // Auto-scroll functionality for carousels
    useEffect(() => {
        if (groupApi) {
            const groupInterval = setInterval(() => {
                if (groupApi.canScrollNext()) {
                    groupApi.scrollNext();
                } else {
                    groupApi.scrollTo(0);
                }
            }, 5000);

            return () => clearInterval(groupInterval);
        }
    }, [groupApi]);

    useEffect(() => {
        if (individualApi) {
            const individualInterval = setInterval(() => {
                if (individualApi.canScrollNext()) {
                    individualApi.scrollNext();
                } else {
                    individualApi.scrollTo(0);
                }
            }, 5000);

            return () => clearInterval(individualInterval);
        }
    }, [individualApi]);

    return (
        <section id="tours" className="bg-gray-50 lg:py-20 md:p-12 p-6">
            <div className="container mx-auto ">
                {/* Group Tours Section */}
                <div className="mb-16">
                    <div className="mb-12 text-center">
                        <h2 className="font-display mb-4 text-3xl font-bold text-gray-900 md:text-4xl">GROUP TOURS</h2>
                        <p className="mx-auto max-w-2xl text-lg text-gray-600">
                            Join other travelers on these popular guided group experiences across Sri Lanka.
                        </p>
                    </div>

                    <Carousel
                        opts={{
                            align: 'start',
                            loop: true,
                        }}
                        className="w-full"
                        setApi={setGroupApi}
                    >
                        <CarouselContent className="py-4">
                            {groupTours.map((tour) => (
                                <CarouselItem key={tour.id} className="sm:basis-1/2 md:basis-1/2 lg:basis-1/3">
                                    <GroupTourCard tour={tour} />
                                </CarouselItem>
                            ))}
                        </CarouselContent>
                    </Carousel>
                </div>

                {/* Individual Tours Section */}
                <div className="">
                    <div className="mb-12 text-center">
                        <h2 className="font-display mb-4 text-3xl font-bold text-gray-900 md:text-4xl">INDIVIDUAL TOURS</h2>
                        <p className="mx-auto max-w-2xl text-lg text-gray-600">
                            Personalized experiences designed for private groups and specific interests.
                        </p>
                    </div>

                    <div className="grid lg:grid-cols-2 md:grid-cols-1  gap-8 py-4 indv">
                        {individualTours.map((tour) => (
                            <IndividualTourCard key={tour.id} tour={tour} />
                        ))}
                    </div>
                </div>
            </div>
        </section>
    );
};

export default TourPackages;
